@@ -1,5 +1,7 @@
+import functools
 import logging
 from datetime import datetime
+from pathlib import Path
 from sys import exit, stderr, stdout
 
 import click
@@ -128,14 +130,21 @@ def common_options(func):
     the execution of the actual function, otherwise options will be
     missing
     """
+    wrapper = click.pass_context(parse_common_options(func))
 
-    func = click.pass_context(parse_common_options(func))
+    for option in (logfile_option, debug_option, config_option, quiet_option,
+                   dry_run_option, yes_option):
+        wrapper = option(wrapper)
 
-    for wrapper in (logfile_option, debug_option, config_option, quiet_option,
-                    dry_run_option, yes_option):
-        func = wrapper(func)
+    functools.update_wrapper(wrapper, func)
 
-    return func
+    return wrapper
+
+
+def cli_entry():
+    from duqtools import fix_dependencies
+    fix_dependencies()
+    cli()
 
 
 @click.group()
@@ -148,9 +157,6 @@ def cli(**kwargs):
 
 
 @cli.command('init')
-@click.option('--full',
-              is_flag=True,
-              help='Create a config file with all possible config values.')
 @click.option('--force', is_flag=True, help='Overwrite existing config.')
 @common_options
 def cli_init(**kwargs):
@@ -175,6 +181,21 @@ def cli_create(**kwargs):
         create(**kwargs)
 
 
+@cli.command('recreate')
+@click.argument('runs', nargs=-1)
+@common_options
+def cli_recreate(**kwargs):
+    """Read `runs.yaml` and re-create the given runs.
+
+    Example:
+    \b
+    - duqtools recreate run_0003 run_0004 --force
+    """
+    from .create import recreate
+    with op_queue_context():
+        recreate(**kwargs)
+
+
 @cli.command('submit')
 @click.option('--force',
               is_flag=True,
@@ -187,6 +208,13 @@ def cli_create(**kwargs):
               '--max_jobs',
               type=int,
               help='Maximum number of jobs to submit.')
+@click.option('-a', '--array', is_flag=True, help='Submit jobs as array.')
+@click.option('-r',
+              '--resubmit',
+              multiple=True,
+              default=tuple(),
+              type=Path,
+              help='Case to re-submit, can be specified multiple times')
 @common_options
 def cli_submit(**kwargs):
     """Submit the UQ runs.
@@ -215,26 +243,35 @@ def cli_status(**kwargs):
 
 @cli.command('plot')
 @click.option('-x',
-              'x_path',
-              default='profiles_1d/*/grid/rho_tor_norm',
+              'grid_var',
+              default='rho_tor_norm',
               type=str,
-              help='IDS of the x value')
+              help='Name of the x (grid) variable')
 @click.option('-y',
-              'y_paths',
+              'data_vars',
               type=str,
-              help='IDS of the y value',
+              help='Name of the y (data) variable(s)',
               multiple=True)
+@click.option('-t',
+              'time_var',
+              type=str,
+              help='Name of the time variable',
+              default='time')
 @click.option('-m',
               '--imas',
               'imas_paths',
               type=str,
               help='IMAS path formatted as <user>/<db>/<shot>/<number>.',
               multiple=True)
-@click.option('-d',
-              '--ids',
-              type=str,
-              default='core_profiles',
-              help='Which IDS to grab data from')
+@click.option('-u', '--user', 'user', type=str, help='IMAS user.')
+@click.option('-d', '--db', 'db', type=str, help='IMAS database.')
+@click.option('-s', '--shot', 'shot', type=int, help='IMAS shot.')
+@click.option('-r',
+              '--runs',
+              'runs',
+              type=int,
+              multiple=True,
+              help='IMAS run (multiple runs can be specified)')
 @click.option('-i',
               '--input',
               'input_files',
@@ -248,12 +285,19 @@ def cli_status(**kwargs):
               help='Output format (json, html, png, svg, pdf), default: html.',
               default=('html', ),
               multiple=True)
-@common_options
 def cli_plot(**kwargs):
-    """Plot some IDS data."""
+    """Plot some IDS data.
+
+    \b
+    Examples:
+    - duqtools plot -x rho_tor_norm -y t_i_ave -y zeff -i data.csv
+    - duqtools plot -y t_i_ave -y zeff -m jet/91234/5
+    - duqtools plot -y zeff -u user -d jet -s 91234 -r 5 -r 6 -r 7
+    - duqtools plot -y zeff -m user/91234/5 -i data.csv
+    - duqtools plot -y zeff -m user/91234/5 -o json
+    """
     from .plot import plot
-    with op_queue_context():
-        plot(**kwargs)
+    plot(**kwargs)
 
 
 @cli.command('clean')
@@ -273,8 +317,9 @@ def cli_clean(**kwargs):
 @click.option('--force', is_flag=True, help='Overwrite files when necessary.')
 @common_options
 def cli_go(**kwargs):
-    """Run create - submit - status - dash in succession, very useful for
-    existing tested and working pipelines
+    """Run create, submit, status, dash in succession.
+
+    Useful for existing tested and working pipelines.
     """
     from .create import create
     from .dash import dash
@@ -283,7 +328,11 @@ def cli_go(**kwargs):
     with op_queue_context():
         create(**kwargs)
     with op_queue_context():
-        submit(**kwargs)
+        submit(max_jobs=None,
+               array=True,
+               schedule=None,
+               resubmit=tuple(),
+               **kwargs)
 
     skwargs = kwargs.copy()
     skwargs['detailed'] = True
@@ -293,6 +342,13 @@ def cli_go(**kwargs):
     dash(**kwargs)
 
 
+@cli.command('yolo')
+@click.pass_context
+def cli_yolo(ctx, **kwargs):
+    """Live on the edge, run `duqtools go --force --yes --quiet`."""
+    ctx.invoke(cli_go, force=True, quiet=True, yes=True)
+
+
 @cli.command('dash')
 @common_options
 def cli_dash(**kwargs):
@@ -310,5 +366,17 @@ def cli_merge(**kwargs):
         merge(**kwargs)
 
 
+@cli.command('list-variables')
+@config_option
+def cli_list_variables(**kwargs):
+    """List available variables.
+
+    Picks up variables from `duqtools.yaml` if it exists in the local
+    directory.
+    """
+    from .list_variables import list_variables
+    list_variables(**kwargs)
+
+
 if __name__ == '__main__':
     cli()
