@@ -9,7 +9,7 @@ logger = logging.getLogger(__name__)
 
 def dash(**kwargs):
     """Start streamlit dashboard."""
-    from streamlit import cli as stcli
+    from streamlit.web import cli as stcli
 
     dashboard_path = files('duqtools.data') / 'dash' / 'dash.py'
 
