@@ -5,7 +5,7 @@ from typing import Sequence
 import streamlit as st
 import xarray as xr
 
-from duqtools.api import Variable
+from duqtools.config import var_lookup
 from duqtools.ids import (ImasHandle, rebase_on_grid, rebase_on_time,
                           standardize_grid)
 
@@ -19,70 +19,62 @@ PREFIX0 = 'profiles_1d/0'
 
 
 @st.experimental_memo
-def get_options(a_run, ids):
-    a_profile = ImasHandle(**a_run).get(ids, exclude_empty=True)
-    return sorted(a_profile.find_by_group('profiles_1d/0/(.*)').keys())
+def get_ids_options():
+    options = tuple(
+        {v.ids
+         for v in var_lookup.values() if (v.type == 'IDS-variable')})
+    return options
+
+
+@st.experimental_memo
+def get_var_options(ids):
+    options = [
+        k for k, v in var_lookup.items()
+        if (v.type == 'IDS-variable') and (v.ids == ids)
+    ]
+    return options
 
 
 @st.experimental_memo
 def get_variables(*, ids: str, x_key: str, y_keys: Sequence[str]):
-    time_var = dict(
-        name='time',
-        ids=ids,
-        path='time',
-        dims=['time'],
-    )
-
-    grid_var = dict(name=x_key, ids=ids, path=f'{PREFIX}/{x_key}', dims=['x'])
-
-    data_vars = tuple(
-        dict(name=y_key, ids=ids, path=f'{PREFIX}/{y_key}', dims=['x'])
-        for y_key in y_keys)
-
     return {
-        'time_var': time_var,
-        'grid_var': grid_var,
-        'data_vars': data_vars,
+        'time_var': 'time',
+        'grid_var': x_key,
+        'data_vars': y_keys,
     }
 
 
 @st.experimental_memo
-def _get_dataset(handles, *, time_var, grid_var, data_vars):
+def _get_dataset(handles, *, ids, time_var, grid_var, data_vars):
     datasets = []
 
-    time_var = Variable(**time_var)
-    grid_var = Variable(**grid_var)
-    data_vars = tuple((Variable(**data_var) for data_var in data_vars))
-
     variables = tuple((time_var, grid_var, *data_vars))
 
     for name, handle in handles.items():
         handle = ImasHandle(**handle)
 
-        data_map = handle.get(grid_var.ids)
-
-        ds = data_map.to_xarray(variables=variables)
+        ds = handle.get_variables(variables=variables)
 
         ds = standardize_grid(
             ds,
-            new_dim=grid_var.name,
-            old_dim=grid_var.dims[0],
+            new_dim=grid_var,
+            old_dim='x',
             new_dim_data=0,
-            group=time_var.name,
+            group=time_var,
         )
         datasets.append(ds)
 
-    reference_grid = datasets[0][grid_var.name].data
+    reference_grid = datasets[0][grid_var].data
 
     datasets = [
-        rebase_on_grid(ds, coord_dim=grid_var.name, new_coords=reference_grid)
+        rebase_on_grid(ds, coord_dim=grid_var, new_coords=reference_grid)
         for ds in datasets
     ]
 
-    reference_time = datasets[0][time_var.name].data
+    reference_time = datasets[0][time_var].data
 
     datasets = [
-        rebase_on_time(ds, time_dim=time_var.name, new_coords=reference_time)
+        rebase_on_time(ds, time_dim=time_var, new_coords=reference_time)
         for ds in datasets
     ]
 
@@ -92,10 +84,11 @@ def _get_dataset(handles, *, time_var, grid_var, data_vars):
     return dataset
 
 
-def get_dataset(handles, *, time_var, grid_var, data_vars):
+def get_dataset(handles, *, ids, time_var, grid_var, data_vars):
     """Convert to hashable types before calling `_get_dataset`."""
     handles = {name: handle.dict() for name, handle in handles.items()}
     return _get_dataset(handles,
+                        ids=ids,
                         time_var=time_var,
                         grid_var=grid_var,
                         data_vars=data_vars)
