@@ -3,9 +3,9 @@ import logging
 from ._handle import ImasHandle
 from ._imas import imas_mocked
 from ._mapping import IDSMapping
-from ._merge import merge_data
-from ._rebase import (rebase_on_grid, rebase_on_time, standardize_grid,
-                      standardize_time)
+from ._merge import merge_data, queue_merge_data
+from ._rebase import (rebase_on_grid, rebase_on_time, standardize_datasets,
+                      standardize_grid, standardize_time)
 
 logger = logging.getLogger(__name__)
 
@@ -15,7 +15,9 @@ __all__ = [
     'merge_data',
     'rebase_on_grid',
     'rebase_on_time',
+    'standardize_datasets',
     'standardize_grid',
     'standardize_time',
     'imas_mocked',
+    'queue_merge_data',
 ]
