@@ -4,13 +4,18 @@ import logging
 import re
 from contextlib import contextmanager
 from pathlib import Path
+from typing import TYPE_CHECKING, Sequence, Union
 
+from ..config import lookup_vars
 from ..operations import add_to_op_queue
-from ..schema import ImasBaseModel
+from ..schema import IDSVariableModel, ImasBaseModel
 from ._copy import copy_ids_entry
 from ._imas import imas, imasdef
 from ._mapping import IDSMapping
 
+if TYPE_CHECKING:
+    import xarray as xr
+
 logger = logging.getLogger(__name__)
 
 PATH_TEMPLATE = ('/afs/eufus.eu/user/g/{user}/public/imasdb/{db}'
@@ -107,12 +112,15 @@ class ImasHandle(ImasBaseModel):
         try:
             copy_ids_entry(self, destination)
         except Exception as err:
-            raise IOError(f'Failed to copy {self}') from err
+            raise OSError(f'Failed to copy {self}') from err
 
     @add_to_op_queue('Removing ids', '{self}')
+    def queue_delete(self):
+        """Queued version of `ImasHandle.delete()`."""
+        return self.delete()
+
     def delete(self):
         """Remove data from entry."""
-
         # ERASE_PULSE operation is yet supported by IMAS as of June 2022
         path = self.path()
         for suffix in SUFFIXES:
@@ -145,22 +153,63 @@ class ImasHandle(ImasBaseModel):
 
         return data
 
-    def get(self, ids: str = 'core_profiles', **kwargs) -> IDSMapping:
+    def get(self, ids: str = 'core_profiles') -> IDSMapping:
         """Map the data to a dict-like structure.
 
         Parameters
         ----------
         ids : str, optional
             Name of profiles to open
-        **kwargs
-            These parameters are passed to initialize `IDSMapping`.
 
         Returns
         -------
         IDSMapping
         """
         raw_data = self.get_raw_data(ids)
-        return IDSMapping(raw_data, **kwargs)
+        return IDSMapping(raw_data)
+
+    def get_variables(
+        self,
+        variables: Sequence[Union[str, IDSVariableModel]],
+        **kwargs,
+    ) -> xr.Dataset:
+        """Get variables from data set.
+
+        This function looks up the data location from the
+        `duqtools.config.var_lookup` table, and returns
+
+        Parameters
+        ----------
+        variables : Sequence[Union[str, IDSVariableModel]]
+            Variable names of the data to load.
+
+        Returns
+        -------
+        ds : xarray
+            The data in `xarray` format.
+        **kwargs
+            These keyword arguments are passed to `IDSMapping.to_xarray()`
+
+        Raises
+        ------
+        ValueError
+            When variables are from multiple IDSs.
+        """
+        var_models = lookup_vars(variables)
+
+        idss = set(var.ids for var in var_models)
+
+        if len(idss) > 1:
+            raise ValueError(
+                f'All variables must belong to the same IDS, got {idss}')
+
+        ids = var_models[0].ids
+
+        data_map = self.get(ids)
+
+        ds = data_map.to_xarray(variables=var_models, **kwargs)
+
+        return ds
 
     def entry(self, backend=imasdef.MDSPLUS_BACKEND):
         """Return reference to `imas.DBEntry.`
@@ -203,11 +252,11 @@ class ImasHandle(ImasBaseModel):
             if cpcode == 0:
                 logger.debug('Data entry created: %s', self)
             else:
-                raise IOError(
+                raise OSError(
                     f'Cannot create data entry: {self}. '
                     f'Create a new db first using `imasdb {self.db}`')
         else:
-            raise IOError(f'Data entry does not exist: {self}')
+            raise OSError(f'Data entry does not exist: {self}')
 
         try:
             yield entry
