@@ -6,6 +6,8 @@ from typing import TYPE_CHECKING, Any, Dict, List, Sequence, Set, Tuple, Union
 
 import numpy as np
 
+from duqtools.config import lookup_vars
+
 from ..schema import IDSVariableModel
 from ._copy import add_provenance_info
 
@@ -14,7 +16,11 @@ if TYPE_CHECKING:
 
     from ._handle import ImasHandle
 
-INDEX_STR = '$index'
+INDEX_STR = '*'
+
+
+class EmptyVarError(Exception):
+    ...
 
 
 def insert_re_caret_dollar(string: str) -> str:
@@ -33,19 +39,23 @@ def replace_index_str(string: str) -> str:
 
 class IDSMapping(Mapping):
 
-    def __init__(self, ids, exclude_empty: bool = True):
-        """__init__
+    def __init__(self, ids):
+        """Map the IMASDB object.
+
+        Empty arrays are excluded from the mapping.
+        You can still get/set these keys directly,
+        but `key in map` returns `False` if `map['key']` is an empty array.
 
         Parameters
         ----------
         ids :
             IMAS DB entry for the IDS.
+
+        Attributes
+        ----------
         exclude_empty : bool
-            Hide empty arrays from mapping. You can still get/set these keys directly,
-            but `key in map` returns `False` if `map['key']` is an empty array.
         """
         self._ids = ids
-        self.exclude_empty = exclude_empty
 
         # All available data fields are stored in this set.
         self._keys: Set[str] = set()
@@ -214,7 +224,7 @@ class IDSMapping(Mapping):
         if not isinstance(val, (np.ndarray, np.generic)):
             return
 
-        if self.exclude_empty and val.size == 0:
+        if val.size == 0:
             return
 
         # We made it here, the value can be stored
@@ -297,24 +307,43 @@ class IDSMapping(Mapping):
 
     def to_xarray(
         self,
-        variables: Sequence[IDSVariableModel],
+        variables: Sequence[Union[str, IDSVariableModel]],
+        empty_var_ok: bool = False,
         **kwargs,
     ) -> xr.Dataset:
         """Return dataset for given variables.
 
         Parameters
         ----------
-        variables : Dict[str, IDSVariableModel]
+        variables : Sequence[Union[str, IDSVariableModel]]
             Dictionary of data variables
+        empty_var_ok : bool
+            If True, silently skip data that are missing from the mapping.
+            If False (default), raise an error when data that are missing
+            from the dataset are requested.
 
         Returns
         -------
         ds : xr.Dataset
             Return query as Dataset
         """
+
+        def _contains_empty(arr):
+            if isinstance(arr, list):
+                return any(_contains_empty(sub_arr) for sub_arr in arr)
+            elif isinstance(arr, np.ndarray):
+                return arr.size == 0
+            elif isinstance(arr(float, int)):
+                return False
+            else:
+                raise ValueError(
+                    f"Don't know how to deal with: {var.name}: {arr}")
+
         import xarray as xr
 
-        xr_data_vars: Dict[str, Tuple[List[str], np.array]] = {}
+        xr_data_vars: Dict[str, Tuple[List[str], np.ndarray]] = {}
+
+        variables = lookup_vars(variables)
 
         for var in variables:
             parts = var.path.split('/*/')
@@ -325,8 +354,15 @@ class IDSMapping(Mapping):
 
             arr = self._fill_array_from_parts(*parts)
 
+            if _contains_empty(arr):
+                if empty_var_ok:
+                    continue
+                else:
+                    raise EmptyVarError(
+                        f'Variable {var.name!r} contains empty data.')
+
             xr_data_vars[var.name] = ([*var.dims], arr)
 
-        ds = xr.Dataset(data_vars=xr_data_vars)
+        ds = xr.Dataset(data_vars=xr_data_vars)  # type: ignore
 
         return ds
