@@ -1,7 +1,9 @@
+from ._job import Job
 from ._system import AbstractSystem
 from ._workdir import WorkDirectory
 
 __all__ = [
     'WorkDirectory',
     'AbstractSystem',
+    'Job',
 ]
