@@ -5,10 +5,10 @@ import logging
 from collections import deque
 from contextlib import contextmanager
 from inspect import signature
-from typing import Callable, Optional
+from typing import Callable, Optional, Sequence
 
 import click
-from pydantic import Field
+from pydantic import Field, validator
 
 from ._logging_utils import duqlog_screen
 from .config import cfg
@@ -16,6 +16,18 @@ from .schema import BaseModel
 
 logger = logging.getLogger(__name__)
 
+OP_STYLE = {'fg': 'green'}
+
+NO_OP_STYLE = {
+    'fg': 'red',
+    'bold': True,
+}
+
+HEADER_STYLE = {
+    'fg': 'red',
+    'bold': True,
+}
+
 
 class Operation(BaseModel):
     """Operation, simple class which has a callable action.
@@ -28,47 +40,18 @@ class Operation(BaseModel):
                         description='print out this operation to the screen')
     description: str = Field(
         description='description of the operation to be done')
-    action: Callable = Field(
+    action: Optional[Callable] = Field(
         description='a function which can be executed when we '
         'decide to apply this operation')
-    args: tuple = Field((),
-                        description='positional arguments that have to be '
-                        'passed to the action')
-    kwargs: dict = Field(None,
-                         description='keyword arguments that will be '
-                         'passed to the action')
-
-    def __init__(self,
-                 action,
-                 description,
-                 extra_description: Optional[str] = None,
-                 *args,
-                 **kwargs):
-        """__init__.
-
-        Parameters
-        ----------
-        description: str
-            description of the operation to be done
-        extra_description: Optional[str]
-            extra description, (not colorized)
-        action: Callable
-            function to be eventually evaluated
-        *args: tuple
-            positional arguments to action
-        **kwargs: dict
-            keyword arguments to action
-        """
-
-        if extra_description:
-            description = click.style(description,
-                                      fg='green') + ' : ' + extra_description
-        super().__init__(action=action,
-                         description=description,
-                         *args,
-                         **kwargs)
-        if not self.kwargs:
-            self.kwargs = {}
+    extra_description: Optional[str] = Field(description='Extra description')
+    args: Optional[Sequence] = Field(
+        None,
+        description='positional arguments that have to be '
+        'passed to the action')
+    kwargs: Optional[dict] = Field(
+        None,
+        description='keyword arguments that will be '
+        'passed to the action')
 
     def __call__(self) -> Operation:
         """Execute the action with the args and kwargs.
@@ -78,10 +61,34 @@ class Operation(BaseModel):
         Operation
             The operation that was executed
         """
-        logger.debug(self.description)
-        self.action(*self.args, **self.kwargs)
+        if self.action:
+            logger.debug(self.long_description)
+            self.action(*self.args, **self.kwargs)  # type: ignore
         return self
 
+    @property
+    def long_description(self):
+        style = NO_OP_STYLE if self.action is None else OP_STYLE
+
+        description = click.style(self.description, **style)
+
+        if self.extra_description is not None:
+            description = f'{description} : {self.extra_description}'
+
+        return description
+
+    @validator('args', always=True)
+    def validate_args(cls, v):
+        if v is None:
+            v = ()
+        return v
+
+    @validator('kwargs', always=True)
+    def validate_kwargs(cls, v):
+        if v is None:
+            v = {}
+        return v
+
 
 class Operations(deque):
     """Operations Queue which keeps track of all the operations that need to be
@@ -105,31 +112,36 @@ class Operations(deque):
             Operations._instance = super().__new__(cls)
         return Operations._instance
 
-    def add(self, *args, **kwargs) -> None:
-        """convenience Operation wrapper around put.
+    def add(self, **kwargs) -> None:
+        """Convenience Operation wrapper around .append().
 
         ```python
         from duqtools.operations import add_to_op_queue.
 
-        op_queue.add(print, args=('Hello World,),
+        op_queue.add(action=print, args=('Hello World,),
                 description="Function that prints hello world")
         ```
         """
+        self.append(Operation(**kwargs))
 
-        self.append(Operation(*args, **kwargs))
+    def add_no_op(self, description: str, extra_description: str = None):
+        """Adds a line to specify an action will not be undertaken."""
+        self.add(action=None,
+                 description=description,
+                 extra_description=extra_description)
 
-    def put(self, item: Operation) -> None:
+    def put(self, item: Operation):
         """synonym for append."""
         self.append(item)
 
-    def append(self, item: Operation) -> None:  # type: ignore
+    def append(self, item: Operation):  # type: ignore
         """Restrict our diet to Operation objects only."""
         if self.enabled:
             logger.debug(
                 f'Appended {item.description} to the operations queue')
             super().append(item)
         else:
-            duqlog_screen.info('- ' + item.description)
+            duqlog_screen.info('- ' + item.long_description)
             item()
 
     def apply(self) -> Operation:
@@ -145,8 +157,7 @@ class Operations(deque):
         and show a fancy progress bar while applying
         """
         from tqdm import tqdm
-        duqlog_screen.info(
-            click.style('Applying Operations', fg='red', bold=True))
+        duqlog_screen.info(click.style('Applying Operations', **HEADER_STYLE))
         if not cfg.quiet:
             with tqdm(total=len(self), position=1) as pbar:
                 pbar.set_description('Applying operations')
@@ -155,8 +166,8 @@ class Operations(deque):
                     while len(self) != 0:
                         op = self.popleft()
                         if not op.quiet:
-                            dbar.set_description(op.description)
-                        logger.info(op.description)
+                            dbar.set_description(op.long_description)
+                        logger.info(op.long_description)
                         pbar.update()
                         op()
         else:
@@ -175,21 +186,28 @@ class Operations(deque):
         # To print the descriptions we need to get them
         duqlog_screen.info('')
         duqlog_screen.info(
-            click.style('Operations in the Queue:', fg='red', bold=True))
-        duqlog_screen.info(click.style('========================', fg='red'))
+            click.style('Operations in the Queue:', **HEADER_STYLE))
+        duqlog_screen.info(
+            click.style('========================', **HEADER_STYLE))
         for op in self:
             if not op.quiet:
-                duqlog_screen.info('- ' + op.description)
+                duqlog_screen.info('- ' + op.long_description)
 
         if self.dry_run:
             duqlog_screen.info('Dry run enabled, not applying op_queue')
             return False
 
+        # Do not confirm if all actions are no-op
+        if all(op.action is None for op in self):
+            duqlog_screen.info('\nNo actions to execute.')
+            return False
+
         ans = self.yes or click.confirm(
-            'Do you want to apply all these operations?', default=False)
+            '\nDo you want to apply all these operations?', default=False)
 
         if ans:
             self.apply_all()
+
         return ans
 
     def check_unconfirmed_operations(self):
@@ -198,9 +216,7 @@ class Operations(deque):
         if len(self) != 0:
             duqlog_screen.warning(
                 click.style((f'There are still {len(self)} operations '
-                             'in the queue at program exit!'),
-                            fg='red',
-                            bold=True))
+                             'in the queue at program exit!'), **HEADER_STYLE))
 
 
 op_queue = Operations()
@@ -215,9 +231,9 @@ def confirm_operations(func):
 
     @confirm_operations
     def complicated_stuff()
-        op_queue.add(print, args=('Hello World,),
+        op_queue.add(action=print, args=('Hello World,),
                 description="Function that prints hello world")
-        op_queue.add(print, args=('Hello World again,),
+        op_queue.add(action=print, args=('Hello World again,),
                 description="Function that prints hello world, again")
     ```
     """
