@@ -10,9 +10,9 @@ from ._basemodel import BaseModel
 class ImasBaseModel(BaseModel):
     """This model describes an IMAS data location."""
     user: str = Field(None, description='Username.')
-    db: str = Field(None, description='IMAS db/machine name.')
-    shot: int = Field(None, description='IMAS Shot number.')
-    run: int = Field(None, description='IMAS Run number.')
+    db: str = Field(description='IMAS db/machine name.')
+    shot: int = Field(description='IMAS Shot number.')
+    run: int = Field(description='IMAS Run number.')
 
     @validator('user', pre=True, always=True)
     def validate_user(cls, v):
