@@ -1,8 +1,11 @@
 import logging
+import subprocess as sp
 from time import sleep
 
+from jetto_tools import config, template
+
 from .config import cfg
-from .jettoduqtools import JettoSettingsManager
+from .jetto._system import jetto_lookup
 from .models import Job, WorkDirectory
 
 logger = logging.getLogger(__name__)
@@ -12,6 +15,10 @@ stream.setFormatter(logging.Formatter('%(message)s'))
 logger.addHandler(stream)
 
 
+class StatusError(Exception):
+    ...
+
+
 class Status():
 
     jobs: list
@@ -117,21 +124,37 @@ class Monitor():
         self.job = job
         self.outfile = None
 
-        self.set_status()
+        jetto_template = template.from_directory(job.dir)
+        jetto_template.lookup.update(jetto_lookup)
+        jetto_config = config.RunConfig(jetto_template)
+
+        self.check_kwmain_flag(jetto_config)
 
         infile = job.in_file
         if not infile.exists():
             debug('%s does not exist, but the job is running', infile)
             return
 
-        jsetmanager = JettoSettingsManager.from_directory(job.dir)
-
-        self.start = jsetmanager.tstart
-        self.end = jsetmanager.tend
+        self.start = jetto_config.start_time
+        self.end = jetto_config.end_time
         self.time = self.start
 
         self.finished = False
 
+        self.set_status()
+
+    def check_kwmain_flag(self, jetto_config):
+        """Check for NLIST2/KWMAIN in jetto.jset. If this flag is not set, the
+        output in `job.out_file` does not contain the output that is grepped
+        for the progress.
+
+        More info: https://github.com/duqtools/duqtools/issues/337
+        """
+        msg = ('Cannot show detailed status, `nlist2.KWMAIN` flag'
+               ' is not set to 1 in `{self.job.status_file}`')
+        if jetto_config['kwmain'] != 1:
+            raise StatusError(msg)
+
     def set_status(self):
         if not self.job.has_status:
             status = 'No status'
@@ -150,14 +173,18 @@ class Monitor():
             f'{self.job.dir.name:8s}, status: {status:12s}')
         self.pbar.refresh()
 
-    def get_lines(self):
-        if not self.outfile:
-            of = self.job.out_file
-            if not of.exists():
-                debug('%s does not exists, but the job is running', of)
-                return []
-            self.output_file = open(of, 'r')
-        return self.output_file.readlines()
+    def get_steptime(self):
+        if not self.job.out_file.exists():
+            debug(
+                f'{self.job.out_file} does not exists, but the job is running')
+            return None
+
+        of = self.job.out_file
+        cmd = f'tac {of} | grep -m 1 ^\\s*STEP'
+        ret = sp.run(cmd, shell=True, capture_output=True)
+        if len(ret.stdout) > 0:
+            return float(ret.stdout.split('=')[2].lstrip(' ').split(' ')[0])
+        return None
 
     def update(self):
         self.set_status()
@@ -170,12 +197,9 @@ class Monitor():
             if not self.job.is_running:
                 return
 
-        lines = self.get_lines()
-        for i in range(len(lines) - 1, 0, -1):
-            if lines[i].startswith(' STEP'):
-                self.time = float(
-                    lines[i].split('=')[2].lstrip(' ').split(' ')[0])
-                break
+        steptime = self.get_steptime()
+        if steptime:
+            self.time = steptime
 
         self.pbar.n = int(100 * (self.time - self.start) /
                           (self.end - self.start))
